<?php
namespace models;

use \ActiveRecord;
use \IoC;

/**
 * Page model class
 * @author Jérôme Brilland
 * @version 1.1
 * @copyright (c) 2021-2023, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class Page extends ActiveRecord {

    protected function validate() {
        $i18n = IoC::resolve( 'i18n' );
        $this->validateMaxLength( 'title', 100, $i18n->__( 'too_long_title', 100 ) );
        $this->validateNotEmpty( 'title', $i18n->__( 'title_cannot_be_empty' ) );
        $this->validateRegExpr( 'title', '#^[A-ZÀ-Ÿa-zà-ÿ0-9_ ]*$#', $i18n->__( 'invalid_title') );
        if ( $this->isNewRecord() || $this->isAttributeChanged( 'title' ) ) {
            $this->validateUnique( 'title', $i18n->__( 'page_already_exists', $this->title ) );
        }
    }

    protected function beforeValidate() {
        $this->title = trim( $this->title );
    }
    
    /**
     * @since 1.1
     * @access protected
     */
    protected function getEncodedurl() {
        return rawurlencode( $this->title );
    }

}
